/*
 * $Id: ThrowableMessageMatcher.java 3561 2011-04-07 15:01:21Z mitcje $
 * $URL: https://open.jira.com/svn/IKASAN/tags/ikasan-recoveryManager-0.9.0-RC3/src/main/java/org/ikasan/exceptionResolver/matcher/ThrowableMessageMatcher.java $
 * 
 * ====================================================================
 * Ikasan Enterprise Integration Platform
 * 
 * Distributed under the Modified BSD License.
 * Copyright notice: The copyright for this software and a full listing 
 * of individual contributors are as shown in the packaged copyright.txt 
 * file. 
 * 
 * All rights reserved.
 *
 * Redistribution and use in source and binary forms, with or without 
 * modification, are permitted provided that the following conditions are met:
 *
 *  - Redistributions of source code must retain the above copyright notice, 
 *    this list of conditions and the following disclaimer.
 *
 *  - Redistributions in binary form must reproduce the above copyright notice, 
 *    this list of conditions and the following disclaimer in the documentation 
 *    and/or other materials provided with the distribution.
 *
 *  - Neither the name of the ORGANIZATION nor the names of its contributors may
 *    be used to endorse or promote products derived from this software without 
 *    specific prior written permission.
 *
 * THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS "AS IS" 
 * AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE 
 * IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE 
 * DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT HOLDER OR CONTRIBUTORS BE LIABLE 
 * FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL 
 * DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR 
 * SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER 
 * CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY,
 * OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE 
 * USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 * ====================================================================
 */
package org.ikasan.exceptionResolver.matcher;

import org.hamcrest.Description;
import org.hamcrest.TypeSafeMatcher;

/**
 * Implementation of <code>TypeSafeMatcher</code> for matching instances of
 * <code>Throwable</code> by considering the message of the
 * <code>Throwable</code>
 * 
 * For now only supports direct matches of a supplied substring within the
 * Throwable's message In future could be extended to support a more powerful
 * regular expression match
 * 
 * @author Ikasan Development Team
 * 
 */
public class ThrowableMessageMatcher extends TypeSafeMatcher<Throwable>
{
    /**
     * substring that may be contained in the Throwable Message
     */
    private String substring;

    /**
     * Constructor
     * 
     * @param substring
     */
    public ThrowableMessageMatcher(String substring)
    {
        this.substring = substring;
    }

    @Override
    public boolean matchesSafely(Throwable throwable)
    {
        return (throwable.getMessage().indexOf(substring) > -1);
    }

    /*
     * (non-Javadoc)
     * 
     * @see org.hamcrest.SelfDescribing#describeTo(org.hamcrest.Description)
     */
    public void describeTo(Description description)
    {
        description.appendText("throwable with message containing [" + substring + "]");
    }
}
